<?php
	class Player {
		// CLASSES
		private $sql = NULL;
		private $tpl = NULL;
		private $func = NULL;
		private $settings = NULL;
		private $stats = NULL;
		
		
		// VARIABLES
		private $appid = NULL;
		private $url = NULL;
		
		// Array of Stats-tables
		private $tables = Array(
			"achievements", 
			"statistics", 
			"ratings",
			"membership"
		);
		
		
		public function __construct() {
			$this->sql  = new MySQL();
			$this->func = new Functions();
			$this->settings = new Settings();
			$this->stats = new Stats();
			$this->tpl  = new Templates();
			$this->tpl->load_phrases("admin", true);
			$this->tpl->load_phrases("_wot_admin", true);
			
			
			$this->appid = json_decode($this->settings->get("properties_key"));
			$this->url = Array(
				'eu' => 'api.worldofwarplanes.eu',
				'na' => 'api.worldofwarplanes.com',
				'ru' => 'api.worldofwarplanes.ru',
				'asia' => 'api.worldofwarplanes.asia'
			);
		}
		
		
		public function add($name, $region, $update=true, $clanname) {
			$name = trim($name);
			
			// Check if name is given
			if ($name == "") {
				return $this->tpl->phrase("message_no_player_given");
			}
			
			// Name is given...
			else {
				// Check if the name is already in the database
				$this->sql->query('SELECT id FROM '.$this->sql->prefix.'player WHERE name = "'.$name.'" AND region = "'.$region.'"');
				
				if($this->sql->count()) {
					// Name is already in the database. Generate message with $name in phrase
					$message = $this->tpl->phrase("message_player_already_added");
					eval ( "\$message = \"$message\";" );
					return $message;
				} 
				else {
					// Name is not in the database yet. Search for the player
					$c=curl_init('http://'.$this->url[$region].'/wowp/account/list/?application_id='.$this->appid->$region.'&search='.$name.'&limit=1');
					curl_setopt($c,CURLOPT_HEADER,false);
					curl_setopt($c,CURLOPT_RETURNTRANSFER,true);
					
					$result = json_decode(curl_exec($c));
					$statuscode = curl_getinfo($c,CURLINFO_HTTP_CODE);
					curl_close($c);
					
					// No connection to API
					if ($statuscode != 200) return "Can't connect to Wargaming API. Please try again later!";
					
					
					// Error thrown from API
					else if (isset($result->status) AND $result->status == "error") return "ERROR: ".$result->error->message;
					
					// No Player was found
					else if (isset($result->count) AND $result->count == 0) {
						$message = $this->tpl->phrase("player_not_found");
						eval ( "\$message = \"$message\";" );
						return $message;
					}
					
					// The wrong Player was found
					else if (strtolower($name) != strtolower($result->data[0]->nickname)) {
						$message = $this->tpl->phrase("player_not_found");
						eval ( "\$message = \"$message\";" );
						return $message;
					}
					
					// Player was found
					else {
						//Create a entry in the "player" table ...
						$this->sql->query('INSERT INTO '.$this->sql->prefix.'player (name, region, account_id, custom) VALUES ("'.$result->data[0]->nickname.'", "'.$region.'", "'.$result->data[0]->account_id.'", "'.$clanname.'")');
						$playerid = $this->sql->id;
						
						// ... and in all stats tables
						$this->sql->query('INSERT INTO '.$this->sql->prefix.'stats__basic (id) VALUES ("'.$playerid.'")');
						$this->sql->query('INSERT INTO '.$this->sql->prefix.'stats__toplist (id) VALUES ("'.$playerid.'")');
						foreach ($this->tables as $table) {
							$this->sql->query('INSERT INTO '.$this->sql->prefix.'stats_'.$table.' (id) VALUES ("'.$playerid.'")');
						}
						
						// Update the players stats
						if ($update) {
							$this->update($playerid, $result->data[0]->nickname, $result->data[0]->account_id, $region);
						}
						
						
						// Generate message with $name in phrase
						$message = $this->tpl->phrase("message_add_player");
						eval ( "\$message = \"$message\";" );
						return $message;
					}
				}
			}
		}
		
		
		public function delete($playerid = NULL, $name = "NoName") {
			if ($playerid === NULL) {
				return "ERROR: No Player-ID given";
			} else {
				$this->sql->query('DELETE FROM '.$this->sql->prefix.'player WHERE id = "'.$playerid.'"');
				$this->sql->query('DELETE FROM '.$this->sql->prefix.'stats__basic WHERE id = "'.$playerid.'"');
				
				foreach ($this->tables as $table) {
					$this->sql->query('DELETE FROM '.$this->sql->prefix.'stats_'.$table.' WHERE id = "'.$playerid.'"');
				}
				
				$message = $this->tpl->phrase("message_delete_player");
				eval ( "\$message = \"$message\";" );
				return $message;
			}
		}
		
		
		public function update($playerid, $name, $account_id, $region) {
			$connection = true;
			
			### ACCOUNT INFO ###
			if (true) {
				$c=curl_init('http://'.$this->url[$region].'/wowp/account/info/?application_id='.$this->appid->$region.'&account_id='.$account_id);
				curl_setopt($c,CURLOPT_HEADER,false); curl_setopt($c,CURLOPT_RETURNTRANSFER,true);
				$result = json_decode(curl_exec($c)); curl_close($c);
				
				if(isset($result->status)) {
					$this->sql->query('
						UPDATE `'.$this->sql->prefix.'player` SET
							`date_stats_update` = "'.time().'",
							`api_player_status` = "'.$result->status.'"
						WHERE `id` = "'.$playerid.'"
					');
					
					if (isset($result->data->$account_id)) {
						$data = $result->data->$account_id;
						
						$this->sql->query('
							UPDATE `'.$this->sql->prefix.'stats__basic` SET
								`created_at` = "'.$data->created_at.'",
								`updated_at` = "'.$data->updated_at.'",
								`xp`                = "'.$data->statistics->xp.'"
							WHERE `id` = "'.$playerid.'"
						');
						
						$this->sql->query('
							UPDATE `'.$this->sql->prefix.'stats__toplist` SET
								`name`              = "'.$data->nickname.'",
								`region`            = "'.$region.'",
								`account_id`        = "'.$account_id.'",
								`kills`             = "'.$data->statistics->frags->total.'",
								`ground_targets`    = "'.$data->statistics->ground_objects_destroyed->total.'",
								`accuracy`          = "'.round(($data->statistics->hits->total / $data->statistics->shots->total *100), 1).'",
								`kills_per_battle`  = "'.round(($data->statistics->frags->total / $data->statistics->battles), 2).'",
								`damage_per_battle` = "'.round(($data->statistics->damage_dealt->total / $data->statistics->battles), 0).'",
								`wlr`               = "'.round(($data->statistics->wins / $data->statistics->losses), 2).'",
								`experience_wo_bonus`   = "'.$data->statistics->base_xp.'",
								`experience_w_bonus`    = "'.$data->statistics->xp.'",
								`xp_per_battle`     = "'.round(($data->statistics->base_xp / $data->statistics->battles), 0).'"
							WHERE `id` = "'.$playerid.'"
						');
						
						/*$this->sql->query('
							UPDATE `'.$this->sql->prefix.'stats_achievements` SET
								`data` = "'.$this->func->convert_object($data->achievements).'"
							WHERE `id` = "'.$playerid.'"
						');*/
						
						$this->sql->query('
							UPDATE `'.$this->sql->prefix.'stats_statistics` SET
								`data` = "'.$this->func->convert_object($data->statistics).'"
							WHERE `id` = "'.$playerid.'"
						');
					}
				}
				
				else $connection = false;
			}
			
			
			### ACCOUNT RATINGS ###
			/*if (true) {
				$c=curl_init('http://'.$this->url[$region].'/wowp/ratings/accounts/?application_id='.$this->appid->$region.'&account_id='.$account_id.'&type=all');
				curl_setopt($c,CURLOPT_HEADER,false); curl_setopt($c,CURLOPT_RETURNTRANSFER,true);
				$statuscode = curl_getinfo($c,CURLINFO_HTTP_CODE);
				$result = json_decode(curl_exec($c)); curl_close($c);
				
				if(isset($result->status) AND isset($result->data->$account_id)) {
					$data = $result->data->$account_id;
					
					$this->sql->query('
						UPDATE `'.$this->sql->prefix.'stats_ratings` SET
							`data` = "'.$this->func->convert_object($data).'"
						WHERE `id` = "'.$playerid.'"
					');
				} 
				
				else $connection = false;
			}*/
			
			
			### RETURN RESULT ###
			if ($connection) {
				return "OK"; 
			} else {
				$this->sql->query('
					UPDATE `'.$this->sql->prefix.'player` SET
						`date_stats_update` = "'.time().'",
						`api_player_status` = "API Error"
					WHERE `id` = "'.$playerid.'"
				');
				return "API Error";
			}
		}
	}
?>